package org.firstinspires.ftc.teamcode.cometbots;

import static org.firstinspires.ftc.teamcode.PedroConstants.MAX_POWER;

import androidx.annotation.NonNull;

import com.acmerobotics.dashboard.telemetry.TelemetryPacket;
import com.acmerobotics.roadrunner.Action;
import com.acmerobotics.roadrunner.SequentialAction;
import com.acmerobotics.roadrunner.SleepAction;
import com.acmerobotics.roadrunner.ftc.Actions;
import com.qualcomm.robotcore.hardware.Gamepad;
import com.qualcomm.robotcore.hardware.HardwareMap;

import org.firstinspires.ftc.robotcore.external.Telemetry;
import org.firstinspires.ftc.teamcode.pedroPathing.follower.Follower;
import org.firstinspires.ftc.teamcode.states.FieldStates;
import org.firstinspires.ftc.teamcode.subsystem.ArmSubsystem;
import org.firstinspires.ftc.teamcode.subsystem.ClawSubsystem;
import org.firstinspires.ftc.teamcode.subsystem.DualMotorSliderSubsystem;
import org.firstinspires.ftc.teamcode.subsystem.MotorsSubsystem;
import org.firstinspires.ftc.teamcode.subsystem.WristSubsystem;

public class CometBotAutoDevelopment {

    /*
    Subsystems
     */
    private DualMotorSliderSubsystem dualSlides;
    private ClawSubsystem claw;
    private WristSubsystem wrist;
    private ArmSubsystem arm;
    /*
    Controllers
     */
    public Gamepad gamepad1;
    public Gamepad gamepad2;
    public Gamepad currentGamepad1;
    public Gamepad currentGamepad2;
    public Gamepad previousGamepad1;
    public Gamepad previousGamepad2;


    private Follower follower;

    public CometBotAutoDevelopment(HardwareMap hardwareMap, Gamepad gamepad1, Gamepad gamepad2) {
        dualSlides = new DualMotorSliderSubsystem(hardwareMap);
        claw = new ClawSubsystem(hardwareMap);
        arm = new ArmSubsystem(hardwareMap);
        wrist = new WristSubsystem(hardwareMap);

        this.gamepad1 = gamepad1;
        this.gamepad2 = gamepad2;
        currentGamepad1 = new Gamepad();
        currentGamepad2 = new Gamepad();
        previousGamepad1 = new Gamepad();
        previousGamepad2 = new Gamepad();
        follower = new Follower(hardwareMap);
    }
    
    public void init() {
        dualSlides.init();
        claw.init();
        wrist.init();
        arm.init();
        follower.setMaxPower(MAX_POWER);
        follower.startTeleopDrive();
    }

    public void update() {
        previousGamepad1.copy(currentGamepad1);
        currentGamepad1.copy(gamepad1);
        previousGamepad2.copy(currentGamepad2);
        currentGamepad2.copy(gamepad2);

        //slides
        dualSlides.update();
        dualSlidesToLowBucketPosition();
        dualSlidesToHighBucketPosition();
        dualSlidesToFloorPosition();
        //arm
        armToParkPosition();
        armAndWristToFloor();
        //claw
        openClaw();
        openThumb();
        follower.setTeleOpMovementVectors(-gamepad1.left_stick_y, -gamepad1.left_stick_x, -gamepad1.right_stick_x);
        follower.update();
    }
    private void openClaw(){
        if(currentGamepad2.right_bumper && !currentGamepad2.right_bumper){
            claw.switchState();
        }
    }
    private void openThumb(){
        if(currentGamepad2.right_bumper && !currentGamepad2.right_bumper){
            claw.switchState();
        }
    }
    private void armAndWristToFloor(){
        if(currentGamepad2.a && !previousGamepad2.a){
            wrist.switchState();
        }
        if(currentGamepad2.a && !previousGamepad2.a){

            double increment = 0.6375 - arm.getPosition();
            for(int i = 0; i < 3; i ++){
                arm.setPosition(arm.getPosition() + increment);
                try {
                    Thread.sleep(50);
                } catch (InterruptedException e) {
                    throw new RuntimeException(e);
                }
            }
            arm.toFloorPosition();


        }


    }
    private void armToBucketPosition(){
        if(currentGamepad2.dpad_up && !previousGamepad2.dpad_up){
            arm.toBucketPosition();
            wrist.toBucketPosition();

        }
    }
    private void armToParkPosition(){
        if(currentGamepad2.x && !previousGamepad2.x){
            arm.toParkPosition();

        }
    }

    private void dualSlidesToHighBucketPosition() {
        if (currentGamepad2.y && !previousGamepad2.y) {
            dualSlides.toHighBucketPosition();
        }
    }
    private void dualSlidesToFloorPosition() {
        if (currentGamepad2.dpad_down && !previousGamepad2.dpad_down) {
            dualSlides.toHighBucketPosition();
        }
    }
    private void dualSlidesToLowBucketPosition() {
        if (currentGamepad2.b && !previousGamepad2.b) {
            dualSlides.toLowBucketPosition();
        }
    }

}
