package org.firstinspires.ftc.teamcode.subsystem;

import static org.firstinspires.ftc.teamcode.PedroConstants.ARM_SERVO;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.armBucket;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.armFloor;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.armPark;

import com.qualcomm.robotcore.hardware.HardwareMap;
import com.qualcomm.robotcore.hardware.ServoImplEx;

public class ArmSubsystem {

    public enum ArmState {
        PARK, FLOOR, BUCKET, SUBMARINE
    }

    private ServoImplEx arm;
    private ArmState state;

    public ArmSubsystem(HardwareMap hardwareMap) {
        this.arm = hardwareMap.get(ServoImplEx.class, ARM_SERVO);
    }

    public void toParkPosition() {
        arm.setPosition(armPark);
        setState(ArmState.PARK);
    }

    public void toFloorPosition() {
        arm.setPosition(armFloor);
        setState(ArmState.FLOOR);
    }

    public void toBucketPosition() {
        arm.setPosition(armBucket);
        setState(ArmState.BUCKET);
    }

    public void setState(ArmState armState) {
        this.state = armState;
    }

    public ArmState getState() {
        return this.state;
    }

    public void init() {
        arm.resetDeviceConfigurationForOpMode();
        toParkPosition();
    }

    public double getPosition() {
        return this.arm.getPosition();
    }

    public void setPosition(double position) {
        this.arm.setPosition(position);
    }

}
