package org.firstinspires.ftc.teamcode.subsystem;

import static org.firstinspires.ftc.teamcode.PedroConstants.CLAW_NAME;
import static org.firstinspires.ftc.teamcode.PedroConstants.THUMB_SERVO;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.clawClose;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.clawOpen;

import com.qualcomm.robotcore.hardware.HardwareMap;
import com.qualcomm.robotcore.hardware.Servo;

public class ClawSubsystem {

    public enum ClawState {
        CLOSED, OPEN
    }

    public enum ThumbState {
        DOWN, UP
    }

    private Servo claw;
    private Servo thumb;
    private ClawState state;
    private ThumbState tState;

    public ClawSubsystem(HardwareMap hardwareMap) {
        claw = hardwareMap.get(Servo.class, CLAW_NAME);
        thumb = hardwareMap.get(Servo.class, THUMB_SERVO);
    }

    public void closeClaw() {
        claw.setPosition(clawClose);
        state = ClawState.CLOSED;
    }

    public void openClaw() {
        claw.setPosition(clawOpen);
        state = ClawState.OPEN;
    }

    public ClawState getState() {
        return state;
    }

    public ThumbState getTState() {
        return tState;
    }

    public void switchState() {
        if (state == ClawState.CLOSED) {
            openClaw();
        } else if (state == ClawState.OPEN) {
            closeClaw();
        }
    }

    public void switchTState() {
        if (tState == ThumbState.UP) {
            thumbDown();
        } else if (tState == ThumbState.DOWN) {
            thumbUp();
        }
    }

    public void init() {
        closeClaw();
        thumbDown();
    }

    public void thumbUp() {
        thumb.setPosition(0.95);
        tState = ThumbState.UP;
    }

    public void thumbDown() {
        thumb.setPosition(0.05);
        tState = ThumbState.DOWN;
    }

}