package org.firstinspires.ftc.teamcode.subsystem;

import static org.firstinspires.ftc.teamcode.PedroConstants.WRIST_SERVO;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.wristBucket;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.wristFloor;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.wristPickup;
import static org.firstinspires.ftc.teamcode.configs.RobotConstants.wristSpeciemen;

import androidx.annotation.NonNull;

import com.acmerobotics.dashboard.telemetry.TelemetryPacket;
import com.acmerobotics.roadrunner.Action;
import com.acmerobotics.roadrunner.ftc.Actions;
import com.qualcomm.robotcore.hardware.HardwareMap;
import com.qualcomm.robotcore.hardware.ServoImplEx;

public class WristSubsystem {

    public enum WristState {
        FLOOR, BUCKET, PICKUP, RUNG, SPECIMEN
    }

    public ServoImplEx wrist;
    public WristState state;

    public WristSubsystem(HardwareMap hardwareMap) {
        this.wrist = hardwareMap.get(ServoImplEx.class, WRIST_SERVO);
    }

    public class MoveToPosition implements Action {
        private double positionValue;
        private WristState positionState;

        public MoveToPosition(double positionValue, WristState positionState) {
            this.positionValue = positionValue;
            this.positionState = positionState;
        }

        @Override
        public boolean run(@NonNull TelemetryPacket telemetryPacket) {
            setState(positionState);
            wrist.setPosition(positionValue);
            telemetryPacket.put("Wrist State", positionState);
            return false;
        }
    }

    public void toFloorPosition() {
        setState(WristState.FLOOR);
        wrist.setPosition(wristFloor);
    }

    public void toBucketPosition() {
        setState(WristState.BUCKET);
        wrist.setPosition(wristBucket);
    }

    public void toPickupPosition() {
        setState(WristState.PICKUP);
        wrist.setPosition(wristPickup);
    }

    public void setState(WristState wristState) {
        this.state = wristState;
    }

    public void switchState() {
        if (state == WristState.FLOOR) {
            toPickupPosition();
        } else if (state == WristState.PICKUP) {
            toFloorPosition();
        }
    }

    public WristState getState() {
        return this.state;
    }

    public void init() {
        wrist.resetDeviceConfigurationForOpMode();
        toPickupPosition();
    }

    public void setPosition(double position) {
        wrist.setPosition(position);
    }

    public double getPosition() {
        return wrist.getPosition();
    }

}
